#ifndef LIGHTS_H__
#define LIGHTS_H__ 1

#define N_LEDS 7
#define N_PWMLEDS 3
#define N_PWMLED_MODES 4

#define N_BUTTONS 2

/* logging.c */
#ifdef USE_LOGGING
void log_set_state(unsigned char val);
void log_init();
void log_flush();
void log_byte(unsigned char byte);
void log_word(uint16_t word);
#else
void inline log_set_state(unsigned char val) { }
void inline log_init() { }
void inline log_flush() { }
void inline log_byte(unsigned char byte) { }
void inline log_word(uint16_t word) { }
#endif

/* adc.c */
void init_adc();
void susp_adc();
void timer_start_adcs();

/* pwm.c */
void init_pwm();
void susp_pwm();
void pwm_off(unsigned char n);
void pwm_set(unsigned char n, uint16_t stride);

/* tmr.c */
extern volatile uint16_t jiffies;
void init_tmr();
void susp_tmr();

/* pwmled.c */
void pwmled_init();
void pwmled_adc(unsigned char n, uint16_t adcval);
void pwmled_set_mode(unsigned char n, unsigned char mode);
unsigned char pwmled_needs_adc(unsigned char n);
unsigned char pwmled_enabled(unsigned char n);

/* gpio.c */
void gpio_init();
void susp_gpio();
void gpio_set(unsigned char n, unsigned char on);
void gpio_before_poweroff();

/* ambient.c */
void ambient_init();
extern volatile unsigned char ambient_zone;
void ambient_adc(uint16_t adc_val);

/* pattern.c */
void pattern_init();
void patterns_next_tick();
void led_set_status(unsigned char status);

/* buttons.c */
void init_buttons();
void timer_check_buttons();

/* main.c */
void hw_setup();
void hw_suspend();
void power_down();

#endif /* !LIGHTS_H__ */

